@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of MIDI files
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1300';
 
 use Moo;
 use strictures 2;
@@ -155,7 +155,14 @@ has _dura_list => (
 );
 
 
-has net => (
+has dura_net => (
+    is       => 'ro',
+    init_arg => undef,
+    default  => sub { {} },
+);
+
+
+has note_net => (
     is       => 'ro',
     init_arg => undef,
     default  => sub { {} },
@@ -215,6 +222,8 @@ sub process {
 
             my @note_group;
             my $note_last;
+            my @dura_group;
+            my $dura_last;
 
             # Accumulate the notes
             for my $event ( @events ) {
@@ -224,9 +233,17 @@ sub process {
                 ( $str = $event->[4] ) =~ tr/0-9/a-j/;
                 $note_text .= "$str ";
 
+                if (@dura_group == $self->ngram_size) {
+                    my $group = join ' ', @dura_group;
+                    $self->dura_net->{ $dura_last . '-' . $group }++ if $dura_last;
+                    $dura_last = $group;
+                    @dura_group = ();
+                }
+                push @dura_group, $event->[2];
+
                 if (@note_group == $self->ngram_size) {
                     my $group = join ' ', @note_group;
-                    $self->net->{ $note_last . '-' . $group }++ if $note_last;
+                    $self->note_net->{ $note_last . '-' . $group }++ if $note_last;
                     $note_last = $group;
                     @note_group = ();
                 }
@@ -536,7 +553,7 @@ MIDI::Ngram - Find the top repeated note phrases of MIDI files
 
 =head1 VERSION
 
-version 0.1201
+version 0.1300
 
 =head1 SYNOPSIS
 
@@ -580,8 +597,9 @@ version 0.1201
         keys %{ $mng->notes->{0} }
   ];
 
-  # Inspect the phrase transition network
-  print Dumper $mng->net;
+  # Inspect the phrase transition networks
+  print Dumper $mng->dura_net;
+  print Dumper $mng->note_net;
 
 =head1 DESCRIPTION
 
@@ -709,10 +727,15 @@ B<process> method.
 The hash-reference bucket of duration ngrams.  Constructed by the
 B<process> method.
 
-=head2 net
+=head2 dura_net
 
-A hash-reference ngram transition network.  Constructed by the
-B<process> method.
+A hash-reference ngram transition network of the durations.
+Constructed by the B<process> method.
+
+=head2 note_net
+
+A hash-reference ngram transition network of the notes.  Constructed
+by the B<process> method.
 
 =head1 METHODS
 
